@@ -33,9 +33,9 @@
 #include "nco_cnf_typ.h" /* Conform variable types */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_prn.h" /* Print variables, attributes, metadata */
-#if (defined NEED_STRCASECMP) || (defined NEED_STRDUP)
+#if (defined NEED_STRCASECMP) || (defined NEED_STRNCASECMP) || (defined NEED_STRDUP)
 # include "nco_sng_utl.h" /* String utilities */
-#endif /* NEED_STRCASECMP || NEED_STRDUP */
+#endif /* NEED_STRCASECMP || NEED_STRNCASECMP || NEED_STRDUP */
 
 #ifdef __cplusplus
 extern "C" {
@@ -48,12 +48,12 @@ nco_mss_val_mk /* [fnc] Return default missing value for type type */
 nco_bool /* O [flg] One or both operands have missing value */
 nco_mss_val_cnf /* [fnc] Change missing_value of var2 to missing_value of var1 */
 (var_sct * const var1, /* I [sct] Variable with template missing value to copy */
- var_sct * const var2); /* I/O [sct] Variable with missing value to fill in/overwrite */
+ var_sct * const var2); /* I/O [sct] Variable with missing value to fill-in/overwrite */
 
 void
 nco_mss_val_cp /* [fnc] Copy missing value from var1 to var2 */
 (const var_sct * const var1, /* I [sct] Variable with template missing value to copy */
- var_sct * const var2); /* I/O [sct] Variable with missing value to fill in/overwrite */
+ var_sct * const var2); /* I/O [sct] Variable with missing value to fill-in/overwrite */
 
 int /* O [flg] Variable has missing value on output */
 nco_mss_val_get /* [fnc] Update number of attributes, missing value of variable */
